/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SCREEN_CONNECTOR_LAUNCHER_SERVICE_IMAGE_FILE_H_
#define SCREEN_CONNECTOR_LAUNCHER_SERVICE_IMAGE_FILE_H_

#include <stdint.h>
#include <unistd.h>

#include "screen_connector_common/export.h"
#include "screen_connector_common/handle.h"

namespace screen_connector {

class EXPORT ImageFile : public Handle<int32_t> {
 public:
  ImageFile(int32_t fd, uint32_t size)
    : Handle<int32_t>(fd, true), size_(size) { }

  virtual ~ImageFile() {
    if (GetRaw() > 0)
      close(GetRaw());
  }

  uint32_t GetSize() const {
    return size_;
  }

 private:
  uint32_t size_;
};

}  // namespace screen_connector

#endif  // SCREEN_CONNECTOR_LAUNCHER_SERVICE_IMAGE_FILE_H_
