/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SCREEN_CONNECTOR_LAUNCHER_SERVICE_RAW_IMAGE_H_
#define SCREEN_CONNECTOR_LAUNCHER_SERVICE_RAW_IMAGE_H_

#include <stdint.h>

#include <memory>
#include <string>

#include "screen_connector_common/handle.h"
#include "screen_connector_common/wl_buffer.h"
#include "screen_connector_launcher_service/direction.h"
#include "screen_connector_launcher_service/image_file.h"
#include "screen_connector_launcher_service/image_type.h"

namespace screen_connector {

class EXPORT RawImage {
 public:
  RawImage(Direction direction,
           int32_t x, int32_t y,
           std::string shared_widget_info,
           std::shared_ptr<ImageFile> image_file);
  RawImage(Direction direction,
           int32_t x, int32_t y,
           std::string shared_widget_info,
           std::shared_ptr<WlBuffer> wl_buffer);
  RawImage(Direction direction,
           int32_t x, int32_t y,
           std::string shared_widget_info,
           std::string file_path);
  RawImage(Direction direction,
           int32_t x, int32_t y,
           std::string shared_widget_info,
           std::string file_path,
           std::string file_group);
  virtual ~RawImage();

  Direction GetDirection() const;
  ImageType GetImageType() const;
  int32_t GetPositionX() const;
  int32_t GetPositionY() const;
  std::string GetSharedWidgetInfo() const;
  std::shared_ptr<ImageFile> GetImageFile() const;
  std::shared_ptr<WlBuffer> GetWlBuffer() const;
  std::string GetFileGroup() const;
  std::string GetFilePath() const;

 private:
  ImageType image_type_;
  Direction direction_;
  int32_t x_;
  int32_t y_;
  std::string shared_widget_info_;
  std::shared_ptr<WlBuffer> wl_buffer_;
  std::shared_ptr<ImageFile> image_file_;
  std::string file_path_;
  std::string file_group_;
};

}  // namespace screen_connector

#endif  // SCREEN_CONNECTOR_LAUNCHER_SERVICE_RAW_IMAGE_H_
