/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <dlog.h>
#include <Ecore_Wl2.h>

#include <memory>

#include "screen_connector_remote_surface_evas/remote_surface_mixed_internal.h"
#include "screen_connector_remote_surface_evas/util.h"

#ifdef LOG_TAG
#undef LOG_TAG
#endif

#define LOG_TAG "SC_REMOTE_SURFACE"
#define SC_TOOLKIT_HANDLE_TAG "SC_TOOLKIT_HANDLE_TAG"

namespace screen_connector {

RemoteSurfaceMixed::RemoteSurfaceMixed(const std::string& id,
                                       RemoteSurface::Type type,
                                       std::shared_ptr<EvasObject> viewer_win,
                                       IWatcherEvent* listener)
    : RemoteSurface(id, type, util::GetWlSurface(*viewer_win.get())),
      listener_(listener), viewer_win_(viewer_win) {
}

RemoteSurfaceMixed:: ~RemoteSurfaceMixed() {
    listener_->OnWatcherRemoved(GetAppId(), GetInstId(), GetPid());
    img_file_.reset();
    img_tbm_.reset();
}

void RemoteSurfaceMixed::OnBufferAdded(const std::string& appId,
                                       const std::string& instId, int pid) {
  listener_->OnWatcherAdded(GetAppId(), GetInstId(), GetPid());
}

void RemoteSurfaceMixed::OnBufferRemoved(const std::string& appId,
                                        const std::string& instId, int pid) {
  listener_->OnWatcherRemoved(GetAppId(), GetInstId(), GetPid());
  img_file_.reset();
  img_tbm_.reset();
}

void RemoteSurfaceMixed::OnBufferChanged(int type,
                                         std::shared_ptr<WlBuffer> tbm,
                                         int fd, uint32_t size, uint32_t time) {
  if (type == TIZEN_REMOTE_SURFACE_BUFFER_TYPE_TBM) {
    if (img_tbm_.get() == nullptr) {
        LOGI("first added !!!! %d %s", type, GetAppId().c_str());
        if (img_file_.get() != nullptr) {
            listener_->OnWatcherRemoved(GetAppId(), GetInstId(), GetPid());
            img_file_.reset();
        }
        img_tbm_.reset(new WatcherImage(evas_object_image_filled_add(
            evas_object_evas_get(viewer_win_->GetRaw())), GetInstId(),
              GetPid(), this));
        listener_->OnWatcherAdded(GetAppId(), GetInstId(), GetPid());
    }
    img_tbm_->UpdateTbm(tbm);
    listener_->OnWatcherChanged(GetAppId(), GetInstId(), GetPid(), *(img_tbm_));
  } else {
    if (img_file_.get() == nullptr) {
        LOGI("first added !!!! %d %s", type, GetAppId().c_str());
        if (img_tbm_.get() != nullptr) {
            listener_->OnWatcherRemoved(GetAppId(), GetInstId(), GetPid());
            img_tbm_.reset();
        }
        img_file_.reset(new WatcherImage(evas_object_image_filled_add(
            evas_object_evas_get(viewer_win_->GetRaw())), GetInstId(),
              GetPid(), this));
        listener_->OnWatcherAdded(GetAppId(), GetInstId(), GetPid());
    }
    img_file_->UpdateFile(fd, size);
    listener_->OnWatcherChanged(GetAppId(),
        GetInstId(), GetPid(), *(img_file_));
  }
}

void RemoteSurfaceMixed::SetChangedEventFilter(
    RemoteSurface::ChangedEventFilter filter) {
  RemoteSurface::SetChangedEventFilter(filter);
  if (filter != FILTER_ALL && filter != FILTER_IMAGE_FILE) {
    RemoteSurface::SetBlock(false);
  } else {
    RemoteSurface::SetBlock(true);
  }
}

}  // namespace screen_connector
