/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "screen_connector_shared_widget_launch/shared_widget_launch.h"
#include "screen_connector_shared_widget_launch/shared_widget_launch_implementation.h"

namespace screen_connector {

SharedWidgetLaunch::Impl::Impl(SharedWidgetLaunch* parent,
                               std::shared_ptr<Wl2Window> wl2_win,
                               SharedWidgetLaunch::IEventListener* listener)
  : parent_(parent),
    wl2_win_(std::move(wl2_win)),
    listener_(listener),
    tzsh_(new Tzsh(tzsh_create(TZSH_TOOLKIT_TYPE_EFL))) {
  auto win_id = ecore_wl2_window_id_get(wl2_win_->GetRaw());
  tzsh_swl_.reset(new TzshSharedWidgetLaunch(
        tzsh_shared_widget_launch_create(tzsh_->GetRaw(),
            static_cast<tzsh_window>(win_id))));
  tzsh_swl_->SetListener(this);
}

void SharedWidgetLaunch::Impl::PrepareDone(
    const std::string& shared_widget_info,
    PrepareState state,
    uint32_t serial) {
  tzsh_swl_->PrepareDone(shared_widget_info, state, serial);
}

void SharedWidgetLaunch::Impl::OnPrepareEvent(PrepareState state,
                                              uint32_t serial) {
  listener_->OnPrepareEvent(state, serial);
}

SharedWidgetLaunch::SharedWidgetLaunch(std::shared_ptr<Wl2Window> wl2_win,
                                       IEventListener* listener)
  : impl_(new Impl(this, std::move(wl2_win), listener)) {
}

SharedWidgetLaunch::~SharedWidgetLaunch() = default;

void SharedWidgetLaunch::PrepareDone(const std::string& shared_widget_info,
    PrepareState state,
    uint32_t serial) {
  impl_->PrepareDone(shared_widget_info, state, serial);
}

}  // namespace screen_connector
