/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SCREEN_CONNECTOR_SHARED_WIDGET_LAUNCH_SHARED_WIDGET_LAUNCH_IMPLEMENTATION_H_
#define SCREEN_CONNECTOR_SHARED_WIDGET_LAUNCH_SHARED_WIDGET_LAUNCH_IMPLEMENTATION_H_

#include <memory>
#include <string>

#include "screen_connector_common/wl2_window.h"
#include "screen_connector_common/tzsh.h"
#include "screen_connector_shared_widget_launch/shared_widget_launch.h"
#include "screen_connector_shared_widget_launch/tzsh_shared_widget_launch_internal.h"

namespace screen_connector {

class SharedWidgetLaunch::Impl : public TzshSharedWidgetLaunch::IEventListener {
 public:
  virtual ~Impl() = default;

  void PrepareDone(const std::string& shared_widget_info,
                   PrepareState state,
                   uint32_t serial);

  void OnPrepareEvent(PrepareState state, uint32_t serial) override;

 private:
  friend class SharedWidgetLaunch;
  Impl(SharedWidgetLaunch* parent,
       std::shared_ptr<Wl2Window> wl2_win,
       SharedWidgetLaunch::IEventListener* listener);

 private:
  SharedWidgetLaunch* parent_;
  std::shared_ptr<Wl2Window> wl2_win_;
  SharedWidgetLaunch::IEventListener* listener_;
  std::unique_ptr<Tzsh> tzsh_;
  std::unique_ptr<TzshSharedWidgetLaunch> tzsh_swl_;
};

}  // namespace screen_connector

#endif  // SCREEN_CONNECTOR_SHARED_WIDGET_LAUNCH_SHARED_WIDGET_LAUNCH_IMPLEMENTATION_H_
